/**************************
	Weather Toolbar
	By Neo101
	Version 1.0.0
**************************/

var SECURITY_ID = max_security_id
var PLUGIN_NAME = 'Weather Toolbar'

var SETTINGS_FILE_NAME = 'Settings.js'
var DEFAULT_SETTINGS_OBJ = {'units' :'C','language' :'English','locationId' :'NLXX0016','locationName' :'The Hague, Netherlands'}

var settings
var language


window.onload = function(){
	settings = getSettings()
	language = getLanguage()

	var url = 'http://weather.yahooapis.com/forecastrss?u=' + settings.units + '&p=' + settings.locationId
	
	loadData(url)
	
	UI.getId('configLink').innerHTML = createConfigControlHTML()
}


function loadData(url){
	UI.getId('weather').innerHTML = translate('loading')
	
	var callBack = {'onFailure': onResponseFailure, 'onSuccess': onResponseSuccess, 'returnXML':true, 'url':url}
	var number = AjaxLib.openConnection(url, 'GET', callBack, null, true)
	AjaxLib.makeCall( number )
}


function onResponseFailure(connectionObject){
	UI.showError('failure error')
}


function onResponseSuccess(responseXML, object){
	if(responseXML == null){
		UI.showError('null error')
	}
	parseData(responseXML)
}


function showData(weatherObj){
	UI.getId('weather').innerHTML = createHTML(weatherObj)
}


function createHTML(weatherObj){
	setConfigControlAlt(weatherObj)
	return createForecastHTML(weatherObj.now, 'now') + createForecastHTML(weatherObj.today, 'today') + 
			createForecastHTML(weatherObj.tomorrow, 'tomorrow') + createRefreshControlHTML(weatherObj)
}


function setConfigControlAlt(weatherObj){
	var text = translate('openConfiguration') + '\n' + 
				translate('currentLocation') + ': ' + translate(weatherObj.location.city) + ', ' + translate(weatherObj.location.country)
	UI.getId('configImage').alt = text
}


function createConfigControlHTML(){
	return ' <img src="images/config.gif" onclick="openConfiguration()" alt="' + translate('openConfiguration') + 
					'" class="configControl" id="configImage"> '
}


function createForecastHTML(weatherDayObj, dayInfo){
	if(weatherDayObj == null || weatherDayObj.icon == null){
		return ''
	}
	var iconSrc = 'images/weatherIcons/' + weatherDayObj.icon + '.gif'
	var info = translate(dayInfo) + ': ' + weatherDayObj.temp + ' &deg;' + settings.units + ' - ' + weatherDayObj.text
	if(weatherDayObj.icon == '3200'){
		return ' <span title="' + info + '">?</span> '
	}
	return ' <img src="' + iconSrc + '" alt="' + info + '"> '
}


function createRefreshControlHTML(weatherObj){
	var updateTime = new Date().toLocaleString()
	var info = translate('reload') + '\n' + 
				translate('lastUpdate') + ': ' + updateTime
	return ' <img src="images/sync.gif" onclick="location.reload()" alt="' + info + '" class="reloadControl"> '
}


function parseData(xmlObj){
	var weatherObj = new Object()
	
	weatherObj.location = new Object()
	weatherObj.location.city = getNode(xmlObj, 'rss/channel/yweather:location/@city')
	weatherObj.location.country = getNode(xmlObj, 'rss/channel/yweather:location/@country')
		
	weatherObj.now = new Object()
	weatherObj.now.temp = getNode(xmlObj, 'rss/channel/item/yweather:condition/@temp')
	weatherObj.now.icon = getNode(xmlObj, 'rss/channel/item/yweather:condition/@code')
	weatherObj.now.text = translate(weatherObj.now.icon)//getNode(xmlObj, 'rss/channel/item/yweather:condition/@text')
	
	
	var nodes = xmlObj.selectNodes('rss/channel/item/yweather:forecast')
	if(nodes[0]){
		weatherObj.today = new Object()
		weatherObj.today.temp = getNode(nodes[0], '@high')
		weatherObj.today.icon = getNode(nodes[0], '@code')
		weatherObj.today.text = translate(weatherObj.today.icon)// getNode(nodes[0], '@text')
	}
	if(nodes[1]){
		weatherObj.tomorrow = new Object()
		weatherObj.tomorrow.temp = getNode(nodes[1], '@high')
		weatherObj.tomorrow.icon = getNode(nodes[1], '@code')
		weatherObj.tomorrow.text = translate(weatherObj.tomorrow.icon)//getNode(nodes[1], '@text')
	}
	
	showData(weatherObj)
}



// XPATH function

function getNode(xml, xpath){
	var node = xml.selectSingleNode(xpath)
	return node ? node.text : ''
}





function openUrl(url){
	external.max_newTab(SECURITY_ID, url)
}


function openConfiguration(){
	var list = 'status:0;help:0;scroll:0;resizable:1;center:1;dialogHeight:330px;dialogWidth:330px'
	var dialog = window.showModalDialog('configuration.html', window, list)
}


function configClose(isChanged){
	if(isChanged == true){
		location.reload()
	}
}


function getSettings(){
	var settingsFileData = MaxLib.readFile(SETTINGS_FILE_NAME)
	if(settingsFileData && settingsFileData != ''){
		eval(settingsFileData)
		return settings
	} else {
		MaxLib.writeFile(SETTINGS_FILE_NAME, 'settings = ' + JsonLib.objectToJSON(DEFAULT_SETTINGS_OBJ))
		return DEFAULT_SETTINGS_OBJ
	}
}


function translate(word){
	if(word in language){
		return language[word]
	}
	return word
}


function getLanguage(){
	var languageFileData = MaxLib.readFile(settings.language + '.js', 'language')
	var language
	if(languageFileData && languageFileData != ''){
		eval(languageFileData)
		return language
	}
	return {}
}


function translateLocation(location){
	var split = location.split(', ')
	for(var i=0; i<split.length; i++){
		split[i] = translate(split[i])
	}
	return split.join(', ')
}

function translateToEnglish(location){
	var locationLow = location.toLowerCase()
	for(var item in language){
		if(language[item].toLowerCase() == locationLow){
			return item
		}
	}
	return location
}

